aboutsummaryrefslogtreecommitdiffstats
path: root/calendar/gui/main.c
diff options
context:
space:
mode:
authorFederico Mena Quintero <federico@helixcode.com>2000-03-12 16:37:12 +0800
committerFederico Mena Quintero <federico@src.gnome.org>2000-03-12 16:37:12 +0800
commit6e515d204a3477cabe2d5dd934ee45406c528ab5 (patch)
treef40b26b7618d2213d021ce5069307c12be7fc2cf /calendar/gui/main.c
parent1f7ba945b16cd5f8c01641dd864a9671d791a651 (diff)
downloadgsoc2013-evolution-6e515d204a3477cabe2d5dd934ee45406c528ab5.tar
gsoc2013-evolution-6e515d204a3477cabe2d5dd934ee45406c528ab5.tar.gz
gsoc2013-evolution-6e515d204a3477cabe2d5dd934ee45406c528ab5.tar.bz2
gsoc2013-evolution-6e515d204a3477cabe2d5dd934ee45406c528ab5.tar.lz
gsoc2013-evolution-6e515d204a3477cabe2d5dd934ee45406c528ab5.tar.xz
gsoc2013-evolution-6e515d204a3477cabe2d5dd934ee45406c528ab5.tar.zst
gsoc2013-evolution-6e515d204a3477cabe2d5dd934ee45406c528ab5.zip
Removed function now that it is no CORBA server in the GUI.
2000-03-12 Federico Mena Quintero <federico@helixcode.com> * gui/main.c (gnome_calendar_locate): Removed function now that it is no CORBA server in the GUI. (save_default_calendar): Removed function. Now the personal calendar server will take care of saving modified calendars when appropriate. (close_cmd): Do not call unregister_calendar_services(). * gui/eventedit.c (ee_ok): Do not save the calendar. * gui/gncal-day-panel.c (day_view_range_activated): Likewise. * gui/gncal-todo.c (ok_button): Likewise. (delete_todo): Likewise. * gui/gncal-full-day.c (delete_occurance): Likewise. (delete_appointment): Likewise. (unrecur_appointment): Likewise. (child_focus_out): Likewise. (update_from_drag_info): Likewise. * gui/gnome-cal.c (gnome_calendar_new): Removed obsolete call to create the CORBA server. * gui/gnome-cal.h (GnomeCalendar): Renamed `calc' field to `client'. * cal-client/cal-client.h (CalClient): Removed filename and corba_server fields. svn path=/trunk/; revision=2102
Diffstat (limited to 'calendar/gui/main.c')
-rw-r--r--calendar/gui/main.c48
1 files changed, 8 insertions, 40 deletions
diff --git a/calendar/gui/main.c b/calendar/gui/main.c
index 3d30c4d1c5..6aca7aa9b8 100644
--- a/calendar/gui/main.c
+++ b/calendar/gui/main.c
@@ -297,31 +297,13 @@ display_objedit_today (GtkWidget *widget, GnomeCalendar *gcal)
gtk_widget_show (ee);
}
-GnomeCalendar *
-gnome_calendar_locate (const char *pathname)
-{
- GList *l;
-
- if (pathname == NULL || pathname [0] == 0)
- pathname = user_calendar_file;
-
- for (l = all_calendars; l; l = l->next){
- GnomeCalendar *gcal = l->data;
-
- if (strcmp (gcal->calc->filename, pathname) == 0){
- return gcal;
- }
- }
- return NULL;
-}
-
static void
close_cmd (GtkWidget *widget, GnomeCalendar *gcal)
{
all_calendars = g_list_remove (all_calendars, gcal);
/* DELETE
- FIX ME -- what do i do here?
+ FIXME -- what do i do here?
if (gcal->cal->modified){
if (!gcal->cal->filename)
save_calendar_cmd (widget, gcal);
@@ -333,10 +315,8 @@ close_cmd (GtkWidget *widget, GnomeCalendar *gcal)
gtk_widget_destroy (GTK_WIDGET (gcal));
active_calendars--;
- if (active_calendars == 0){
- unregister_calendar_services ();
+ if (active_calendars == 0)
gtk_main_quit ();
- }
}
void
@@ -483,7 +463,7 @@ save_ok (GtkWidget *widget, GtkFileSelection *fs)
gtk_window_set_wmclass (GTK_WINDOW (gcal), "gnomecal", "gnomecal");
fname = g_strdup (gtk_file_selection_get_filename (fs));
- /* calendar_save (gcal->cal, fname); DELETE / FIX ME*/
+ /* calendar_save (gcal->cal, fname); DELETE / FIXME*/
g_free(fname);
gtk_main_quit ();
}
@@ -566,18 +546,6 @@ save_calendar_cmd (GtkWidget *widget, void *data)
}
#endif /* 0 */
-/*
- * Saves @gcal if it is the default calendar
- */
-void
-save_default_calendar (GnomeCalendar *gcal)
-{
- if (!gcal->calc->filename)
- return;
-
- /* save_calendar_cmd (NULL, gcal); FIX ME */
-}
-
static GnomeUIInfo gnome_cal_file_menu [] = {
GNOMEUIINFO_MENU_NEW_ITEM(N_("_New calendar"),
N_("Create a new calendar"),
@@ -585,7 +553,7 @@ static GnomeUIInfo gnome_cal_file_menu [] = {
GNOMEUIINFO_MENU_OPEN_ITEM(open_calendar_cmd, NULL),
- /* GNOMEUIINFO_MENU_SAVE_ITEM(save_calendar_cmd, NULL), FIX ME */
+ /* GNOMEUIINFO_MENU_SAVE_ITEM(save_calendar_cmd, NULL), FIXME */
GNOMEUIINFO_MENU_SAVE_AS_ITEM(save_as_calendar_cmd, NULL),
@@ -817,7 +785,7 @@ dump_events (void)
printf ("%s -- %s\n", start, end);
printf (" %s\n", co->ico->summary);
}
- /* calendar_destroy_event_list (l); DELETE / FIX ME */
+ /* calendar_destroy_event_list (l); DELETE / FIXME */
/* calendar_destroy (cal); DELETE */
exit (0);
}
@@ -980,7 +948,7 @@ session_save_state (GnomeClient *client, gint phase, GnomeRestartStyle save_styl
argv [i++] = "--view";
argv [i++] = gnome_calendar_get_current_view_name (gcal);
free_list = g_list_append (free_list, geometry);
- /* calendar_save (gcal->cal, gcal->cal->filename); FIX ME */
+ /* calendar_save (gcal->cal, gcal->cal->filename); FIXME */
}
argv [i] = NULL;
gnome_client_set_clone_command (client, i, argv);
@@ -1089,7 +1057,7 @@ main (int argc, char **argv)
/* FIX ME -- where should this go? */
void
calendar_iterate (GnomeCalendar *cal,
time_t start, time_t end,
@@ -1122,7 +1090,7 @@ calendar_object_compare_by_start (gconstpointer a, gconstpointer b)
return (diff < 0) ? -1 : (diff > 0) ? 1 : 0;
}
/* FIX ME -- where should this (and calendar_object_compare_by_start) go? */
/* returns a list of events in the form of CalendarObject* */
GList *calendar_get_events_in_range (CalClient *calc,
time_t start, time_t end)
@@ -1089,7 +1057,7 @@ main (int argc, char **argv)
gnome_client_set_clone_command (client, i, argv);
-/* FIX ME -- where should this go? */
+/* FIXME -- where should this go? */
void
calendar_iterate (GnomeCalendar *cal,
@@ -1122,7 +1090,7 @@ calendar_object_compare_by_start (gconstpointer a, gconstpointer b)
return (diff < 0) ? -1 : (diff > 0) ? 1 : 0;
}
-/* FIX ME -- where should this (and calendar_object_compare_by_start) go? */
+/* FIXME -- where should this (and calendar_object_compare_by_start) go? */
/* returns a list of events in the form of CalendarObject* */
GList *calendar_get_events_in_range (CalClient *calc,